@@ -64,24 +64,28 @@ roger_checkreq <- function(file = "./requirements.txt", ...,
     system2("roger", args = unlist(Call, use.names = FALSE), ...)
 }
 
-roger_clone <- function(project, pattern, page_limit = NULL, machine = NULL,
-                        curl_options = NULL, api, ..., .debugOnly = FALSE)
+roger_clone <- function(pattern, project, rogerrc_file = NULL,
+                        machine = NULL, curl_options = NULL,
+                        api = NULL, quiet = FALSE, ...,
+                        .debugOnly = FALSE)
 {
     ## Extract tool name and arguments; keep options.
     Call <- get_cli_opts(match.call())
     opts <- Call$opts[-c(1L, 2L)]
 
-    ## Quote 'page_limit' and 'machine' CLI options and prepend with
-    ## corresponding flag.
-    flags <- c(api = "--api=",
-               page_limit = "--page-limit=",
-               machine = "--machine=")
+    ## Quote non-boolean CLI options and prepend with corresponding
+    ## flags. Leave 'curl_options' untouched, if any.
+    flags <- c(rogerrc_file = "--rogerrc-file=",
+               machine = "--machine=",
+               api = "--api=")
     opts[names(flags)] <- format_opts(opts[names(flags)], flags)
 
+    ## Boolean argument 'quiet' translates into an option without a
+    ## value.
+    opts$quiet <- if (quiet) "--quiet"
+
     ## Rewrite complete list of CLI arguments in suitable order.
-    ## Note: a terminating '--' is not needed as 'curl_options' is
-    ## never last in the call built here.
-    Call$opts <- c(opts, shQuote(Call$opts[c("pattern", "project")]))
+    Call$opts <- c(opts, "--", shQuote(c(pattern, project)))
 
     ## Print command as string in debugging mode.
     if (.debugOnly)
@@ -92,28 +96,31 @@ roger_clone <- function(project, pattern, page_limit = NULL, machine = NULL,
     system2("roger", args = unlist(Call, use.names = FALSE), ...)
 }
 
-roger_grade <- function(dir, config_file = NULL, time_limit = NULL,
-                        detached_head = FALSE, output_file = NULL, ...,
+roger_grade <- function(dir = getwd(), config_file = NULL,
+                        time_limit = NULL, detached_head = FALSE,
+                        output_file = NULL, quiet = FALSE, ...,
                         .debugOnly = FALSE)
 {
-    ## Extract tool name and arguments; keep options.
+    ## Extract tool name and arguments; keep argument with a default
+    ## value and options.
     Call <- get_cli_opts(match.call())
-    opts <- Call$opts[-1L]
+    opts <- Call$opts
 
     ## Quote non-boolean CLI options and prepend with corresponding
-    ## flag.
+    ## flags. This also drops the argument with a default value from
+    ## the options list.
     flags <- c(config_file = "--config-file=",
                time_limit = "--time-limit=",
                output_file = "--output-file=")
     opts <- format_opts(opts[names(flags)], flags)
 
-    ## Boolean argument 'detached_head' translates into an option
-    ## without a value.
-    opts$detached_head <-
-        if (detached_head) "--detached-head" else NULL
+    ## Boolean argument 'detached_head' and 'quiet' translate into an
+    ## option without a value.
+    opts$detached_head <- if (detached_head) "--detached-head"
+    opts$quiet <- if (quiet) "--quiet"
 
     ## Rewrite complete list of CLI arguments in suitable order.
-    Call$opts <- c(opts, shQuote(Call$opts["dir"]))
+    Call$opts <- c(opts, shQuote(dir))
 
     ## Print command as string in debugging mode.
     if (.debugOnly)
@@ -124,13 +131,14 @@ roger_grade <- function(dir, config_file = NULL, time_limit = NULL,
     system2("roger", args = unlist(Call, use.names = FALSE), ...)
 }
 
-roger_push <- function(repos, branch, create = FALSE, file = NULL,
-                       add_file = NULL, message = NULL, quiet = FALSE, ...,
-                       .debugOnly = FALSE)
+roger_push <- function(branch, repos = getwd(), create = FALSE,
+                       file = NULL, add_file = NULL, message = NULL,
+                       quiet = FALSE, ..., .debugOnly = FALSE)
 {
-    ## Extract tool name and arguments; keep options.
+    ## Extract tool name and arguments; keep argument with a default
+    ## value and options.
     Call <- get_cli_opts(match.call())
-    opts <- Call$opts[-c(1L, 2L)]
+    opts <- Call$opts[-1L]
 
     ## Argument 'add_file' can be a vector of file names. Each file
     ## name requires a flag in front to generate multiple options in
@@ -147,13 +155,16 @@ roger_push <- function(repos, branch, create = FALSE, file = NULL,
     flags <- c(file = "--file=")
     opts[names(flags)] <- format_opts(opts[names(flags)], flags)
 
+    ## Drop the argument with a default value from the options list.
+    opts$repos <- NULL
+
     ## Boolean arguments 'create' and 'quiet' translate into options
     ## without a value.
-    opts$create <- if (create) "--create" else NULL
-    opts$quiet <- if (quiet) "--quiet" else NULL
+    opts$create <- if (create) "--create"
+    opts$quiet <- if (quiet) "--quiet"
 
     ## Rewrite complete list of CLI arguments in suitable order.
-    Call$opts <- c(opts, shQuote(Call$opts[c("branch", "repos")]))
+    Call$opts <- c(opts, shQuote(c(branch, repos)))
 
     ## Print command as string in debugging mode.
     if (.debugOnly)
@@ -164,19 +175,23 @@ roger_push <- function(repos, branch, create = FALSE, file = NULL,
     system2("roger", args = unlist(Call, use.names = FALSE), ...)
 }
 
-roger_switch <- function(repos, branch, quiet = FALSE, ...,
-                         .debugOnly = FALSE)
+roger_switch <- function(branch, repos = getwd(), quiet = FALSE,
+                         ..., .debugOnly = FALSE)
 {
-    ## Extract tool name and arguments; keep options.
+    ## Extract tool name and arguments; keep argument with a default
+    ## value and options.
     Call <- get_cli_opts(match.call())
-    opts <- Call$opts[-c(1L, 2L)]
+    opts <- Call$opts[-1L]
+
+    ## Drop the argument with a default value from the options list.
+    opts$repos <- NULL
 
     ## Boolean argument 'quiet' translates into an option without a
     ## value.
-    opts$quiet <- if (quiet) "--quiet" else NULL
+    opts$quiet <- if (quiet) "--quiet"
 
     ## Rewrite complete list of CLI arguments in suitable order.
-    Call$opts <- c(opts, shQuote(Call$opts[c("branch", "repos")]))
+    Call$opts <- c(opts, shQuote(c(branch, repos)))
 
     ## Print command as string in debugging mode.
     if (.debugOnly)
@@ -187,29 +202,30 @@ roger_switch <- function(repos, branch, quiet = FALSE, ...,
     system2("roger", args = unlist(Call, use.names = FALSE), ...)
 }
 
-roger_validate <- function(dir, config_file = NULL,
+roger_validate <- function(dir = getwd(), config_file = NULL,
                            check_local_repos = TRUE, ...,
                            .debugOnly = FALSE)
 {
     ## Extract tool name and arguments; keep options.
     Call <- get_cli_opts(match.call())
-    opts <- Call$opts[-1L]
+    opts <- Call$opts
 
     ## Quote non-boolean CLI options and prepend with corresponding
-    ## flag.
+    ## flags. This also drops the argument with a default value from
+    ## the options list.
     flags <- c(config_file = "--config-file=")
     opts <- format_opts(opts[names(flags)], flags)
 
     ## Boolean argument 'check_local_repos' translates into an option
     ## without a value (with an inverted logic).
     opts$check_local_repos <-
-        if (check_local_repos) NULL else "--no-check-local-repos"
+        if (!check_local_repos) "--no-check-local-repos"
 
     ## Keep only first directory name.
     Call$opts$dir <- Call$opts$dir[1L]
 
     ## Rewrite complete list of CLI arguments in suitable order.
-    Call$opts <- c(opts, shQuote(Call$opts["dir"]))
+    Call$opts <- c(opts, shQuote(dir))
 
     ## Print command as string in debugging mode.
     if (.debugOnly)
